@@ -11,12 +11,8 @@ class ConfigSettingsManager(models.Manager):
         else:
             cms_settings = CMSSettings.objects.get_settings()
             config_settings = self.get_query_set().create()
-            try:
-                domain = cms_settings.domain
-            except AttributeError:
-                domain = cms_settings.project_name + '.com'
-            ConfigSite.objects.create(settings=config_settings, site='www.%s' % domain)
-            ConfigRedirect.objects.create(settings=config_settings, site='%s' % domain)
+            ConfigSite.objects.create(settings=config_settings, site='www.%s.com' % cms_settings.project_name)
+            ConfigRedirect.objects.create(settings=config_settings, site='%s.com' % cms_settings.project_name)
             return config_settings
 
 class ConfigSettings(BaseSettings):
@@ -34,4 +30,4 @@ class ConfigAppMedia(models.Model):
     settings = models.ForeignKey(ConfigSettings, related_name='appmedia')
     appname = models.CharField(verbose_name=_('Application name'), max_length=255)
     source = models.CharField(verbose_name=_('Source dir'), max_length=255)
-    target = models.CharField(verbose_name=_('target dir'), max_length=255)
+    target = models.CharField(verbose_name=_('target dir'), max_length=255)
\ No newline at end of file
