@@ -1,6 +1,8 @@
 import os
+import re
 import sys
 import warnings
+import ConfigParser
 
 from django.conf import settings
 from django.contrib import admin
@@ -14,7 +16,9 @@ def make_config(template_name):
     from config.settings import media_url, media_path, \
         admin_media_url, admin_media_path, project_name, project_file, \
         media_paths, sites, redirects, need_auth, settings, static_url, \
-        static_root
+        static_root, duply_db_backup_temp_dir
+    duply_globals = get_backup_config()
+    project_root = get_project_root()
     staticfiles = STATIC_FILES_INSTALLED
     return render_to_string(template_name, locals())
 
@@ -86,3 +90,32 @@ def get_media_paths():
     # It won't change, so convert it to a tuple to save memory.
     paths = tuple([ (url, path) for url, path in paths.iteritems() ])
     return paths
+
+#===============================================================================
+# Backup routines
+#===============================================================================
+def get_project_root():
+    urlconf_module = import_model(settings.ROOT_URLCONF)
+    return os.path.abspath(os.path.dirname(os.path.dirname(urlconf_module.__file__)))
+
+def get_backup_config():
+    from config.settings import duply_globals, project_name
+    try:
+        from collections import OrderedDict
+    except:
+        from ordereddict import OrderedDict
+
+    if duply_globals is not None:
+        config = ConfigParser.RawConfigParser(dict_type=OrderedDict)
+        try:
+            config.read(duply_globals)
+        except IOError:
+            raise
+
+        # Find TAGET setting and append project name:
+        target = config.get('duply', 'target')
+        target = re.sub('^[\'\"](.*)[\'\"]$', '"\g<1>%s"' % project_name, target)
+        config.set('duply', 'target', target)
+        return config.items('duply')
+    else:
+        return None
